#!/bin/sh
# $Id: t-dkim-1.sh,v 1.8 2013/12/13 02:08:16 ca Exp $
# Copyright (c) 2010 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ----------------------------------------
# DKIM signing, using multiple domains
# uses mcpmts.sh
# ----------------------------------------
#

# source directory of this (and other) shell script
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../chkmts
fi
. ${SD}/common.sh

# cd to right directory
cd ../qmgr || exit 1
rm -f ${MTMAP}

chkcto smtps MTA_USE_DKIM

if test X"`uname`" != "XOSF1"
then
while getopts O:p:s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

# create directory to pass socket
test -d smtps || mkdir smtps

# create aliases
cat > ${ALI} <<EOF
abuse:	local:
postmaster:	local:
user:	local:
EOF
# create map
rm -f ${ALIMAP}
${MM} < ${ALI}

# create mailertable (save old version?)
cat > ${MT} <<EOF
local.dom	lmtp:
example.net	[127.0.0.1]
EOF

Here=`pwd`
cd $SD/../libdkim || exit
K=`pwd`
cd $Here || exit

MSG=msg
OK=ok

# ----------------------------------------
# simple/simple
TEST=1
if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >${SMXCNF} <<EOF
smtps { log_level = 12;pass_fd_socket = smtps/smtpsfd; wait_for_server=4;
	listen_socket { type=inet; port=${SRVPORT}; }
	start_action = pass; user = ${USER};
	path = ../smtps/smtps;
	arguments = "smtps -9 ${DKTIME} -f ${SMXCNF} ${MTA_SERVER_OPTIONS}";
 DKIM_signing {
   sign {
    domain=example.com;
    selector=default;
    keyfile=${K}/private.key; }
   sign {
    from=example.net;
    domain=example.net;
    selector=net;
    keyfile=${K}/net.key; }
  
  }
}
smtpc { log_level = 12;remote_port = ${SNKPORT}; wait_for_server=4;
	start_action = wait; user = ${USER};
	path = "../smtpc/smtpc"; arguments = "smtpc -f ${SMXCNF}";
}
qmgr { log_level = 12;wait_for_server=4; wait_for_client=4; 
	start_action = wait; user = ${USER};
	restart_dependencies = { smtps,smtpc,smar, };
	path = "../qmgr/qmgr"; arguments = "qmgr -f ${SMXCNF}";
}
smar { log_level = 12;
	start_action = wait; user = ${USER};
	restart_dependencies = { smtps,qmgr };
	path = "../smar/smar"; arguments = "smar -f ${SMXCNF}";
}
EOF

clearlogs

cat > ${MSG} <<EOF
From: user@example.net
To: recipient@sendmail.net
Subject: test DKIM

2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
EOF

# ----------------------------------------
if ${SHELL} ${SD}/mcpmts.sh -13 lmtpsock -Ssender@example.net -Ruser@local.dom -E 0 -X 0 -A 1 -Z smtpc2 -c "-D ${MSG}" "$@"
then
  if test -s ${B1}
  then
     ${EGREP} -v '^Return-Path: ' ${B1} |\
	 ${SED} -e '/^Received:/,/^	id /d' > ${OUT}

     cat > ${OK} <<EOF
DKIM-Signature: v=1; a=rsa-sha256; c=simple/simple; d=example.net;
	s=net; t=1258487282;
	bh=P7M5AsnZKX0CSpQl3w3u9XwzYQ7gDrSE5gSSQy/1W2E=; h=Subject:To:From;
	b=Qew46oJYyx+7GWVcRxGJg+Yh3ap+YLN8O6TgKlUA+o7v6Uf1fiJ3WiAiUUEs
	 cMUX3LYSM9IJZXDUtAq0k4qQfnqy/zhtKAV7bGphzuZNvm82tVKzZDbrOfIe/
	 NszfAikL4fkq15Vie80AEwkJI+nE9hnZ46yTZzCcaTmRL7wVqI=
From: user@example.net
To: recipient@sendmail.net
Subject: test DKIM

2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net

.
EOF
    if ${DIFF} -w ${OK} ${OUT} >/dev/null
    then
      :
    else
      ERR=true
    fi
  else
     ERR=true
  fi
else
  echo "$0: test ${TEST} failed"
  ERR=true
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && exit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi

# ----------------------------------------
# simple/simple
TEST=2
if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >${SMXCNF} <<EOF
smtps { log_level = 12;pass_fd_socket = smtps/smtpsfd; wait_for_server=4;
	listen_socket { type=inet; port=${SRVPORT}; }
	start_action = pass; user = ${USER};
	path = ../smtps/smtps;
	arguments = "smtps -9 ${DKTIME} -f ${SMXCNF} ${MTA_SERVER_OPTIONS}";
 DKIM_signing {
   sign {
    domain=example.com;
    selector=default;
    keyfile=${K}/private.key; }
   sign {
    from=example.net;
    domain=example.net;
    selector=net;
    keyfile=${K}/net.key; }
  }
}
smtpc { log_level = 12;remote_port = ${SNKPORT}; wait_for_server=4;
	start_action = wait; user = ${USER};
	path = "../smtpc/smtpc"; arguments = "smtpc -f ${SMXCNF}";
}
qmgr { log_level = 12;wait_for_server=4; wait_for_client=4; 
	start_action = wait; user = ${USER};
	restart_dependencies = { smtps,smtpc,smar, };
	path = "../qmgr/qmgr"; arguments = "qmgr -f ${SMXCNF}";
}
smar { log_level = 12;
	start_action = wait; user = ${USER};
	restart_dependencies = { smtps,qmgr };
	path = "../smar/smar"; arguments = "smar -f ${SMXCNF}";
}
EOF

clearlogs

cat >${MSG} <<EOF
From: "This A. User" <user@example.net>
To: Not Really <recipient@sendmail.net>, But A Lst <r2@example.com>
Subject: Testing DKIM signing with MeTA1
Message-Id: <123456789.abcdeXYZ@example.net>
Date: Fri, 27 Dec 2010 17:20:05 -0000 (GMT)

This is the message body. It's nice, isn't it?
It does not contain anything useful,
but that is the case with most e-mails.

More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
-- 
This might be a signature virus
.
EOF

# ----------------------------------------
if ${SHELL} ${SD}/mcpmts.sh -13 lmtpsock -Ssender@example.net -Ruser@local.dom -E 0 -X 0 -A 1 -Z smtpc2 -c "-D ${MSG}" "$@"
then
  if test -s ${B1}
  then
     ${EGREP} -v '^Return-Path: ' ${B1} |\
	 ${SED} -e '/^Received:/,/^	id /d' > ${OUT}

     cat > ${OK} <<EOF
DKIM-Signature: v=1; a=rsa-sha256; c=simple/simple; d=example.net;
	s=net; t=1258487282;
	bh=0UJfgPAKs0CsoCKDyE2F/DURzgkyqelLb9RVT2C4wDQ=; h=Date:Message-Id:Subject:To:From;
	b=ZPh316pbuKjME69mcQ69/L649ykQTpB+D2p6Gy5MiAsFk/dH7E/TeKLgv9al
	 /+gcvbx6G3OgUP9f1vY9onfWJWHLbB47W5OVu1NFVMyXuWAmLgOyr0udkYvJl
	 FUeFXaq6Npyfe8iajIjnfozIAAuqU6lRwFaOtpGw4s26L+AKwY=
From: "This A. User" <user@example.net>
To: Not Really <recipient@sendmail.net>, But A Lst <r2@example.com>
Subject: Testing DKIM signing with MeTA1
Message-Id: <123456789.abcdeXYZ@example.net>
Date: Fri, 27 Dec 2010 17:20:05 -0000 (GMT)

This is the message body. It's nice, isn't it?
It does not contain anything useful,
but that is the case with most e-mails.

More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
More message content. To fill up the buffer.
More message content. To fill up the buffers.
-- 
This might be a signature virus
.
EOF

    if ${DIFF} -w ${OK} ${OUT} >/dev/null
    then
      :
    else
      ERR=true
    fi
  else
     ERR=true
  fi
else
  echo "$0: test ${TEST} failed"
  ERR=true
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && exit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi



# ----------------------------------------
# end
if test ${ERRS} -eq 0
then
#  rm -f ${MSG} ${OK} ${OUT}
  exit 0
else
  echo "$0: ${ERRS} error(s)"
  exit 1
fi
