#!/bin/sh
# $Id: t-pm-exit-1.sh,v 1.10 2011/10/20 15:07:14 ca Exp $
# Copyright (c) 2005 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ----------------------------------------
# test pmilter exit()ing during some commands, continue SMTP session
# uses smtpcnf.sh.
# ----------------------------------------
#

SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../chkmts
fi
. ${SD}/common.sh
V=0

chkcto smtps MTA_USE_PMILTER '(--enable-pmilter)'

if test X"`uname`" = "XLinux"
then
  echo "SKIPPED: $0: on Linux, needs POSIX conformant pthread implementation"
  exit 0
fi
if test X"`uname`" = "XOSF1"
then
  echo "SKIPPED: $0: on OSF1, causes ksh core dump"
  exit 0
fi

OUT="t-pm-exit-1.out"
PMPRG="-p ../libpmilter/t-pmilter-1"
PMOPT=""

if test X"`uname`" != "XOSF1"
then
while getopts O:p:s:V FLAG
do
  case "${FLAG}" in
    O) PMOPT="${PMOPT} ${OPTARG}";;
    p) PMPRG="-p ${OPTARG}";;
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

# cd to right directory (where the programs will be executed).
cd ../qmgr || myexit 1
rm -f ${MTMAP}

${CAT} > ${SMXCNF} <<EOF
qmgr { Log_Level = 12; wait_for_server=4; wait_for_client=4; }
smar { Log_Level = 12; nameserver = ${NS}; }
smtpc { Log_Level = 12; remote_port=${SNKPORT}; wait_for_server=4; }
smtps {
Log_Level = 14;
daemon_address = localhost:${SRVPORT};
wait_for_server=4;
policy_milter { socket {type=unix; path="pmilter.sock";} timeout=20;
 flags=accept_but_reconnect;}
}
EOF

# ----------------------------------------
# MAIL command causes pmilter to exit
TEST=1
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
RCPT=x${TEST}@y.z
rm -f ${PMIDS}
PMOPTS="-r m=${PMEXIT}"
if ${SHELL} ${SCRIPTS}/smtpcnf.sh -V '-d 8' ${PMPRG} ${PMOPT} -P "${PMOPTS}" -Z 'smtpc2' -c '-E' -E 1 -A 1 -X 1 "$@" -Sa${TEST}@b.c -R${RCPT} -8 s
then
  ERR=false
else
    ERR=true
    echo "$0: test ${TEST} failed"
    test X"${MTA_STOPONERROR}" != X && myexit 1
fi
rm -f ${PMIDS}

if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && myexit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi


# ----------------------------------------
# RCPT command causes pmilter to exit
TEST=2
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
RCPT=x${TEST}@y.z
rm -f ${PMIDS}
PMOPTS="-r r=${PMEXIT}"
if ${SHELL} ${SCRIPTS}/smtpcnf.sh -V '-d 8' ${PMPRG} ${PMOPT} -P "${PMOPTS}" -Z 'smtpc2' -c '-E' -E 1 -A 1 -X 1 "$@" -Sa${TEST}@b.c -R${RCPT} -8 s
then
  ERR=false
else
    ERR=true
    echo "$0: test ${TEST} failed"
    test X"${MTA_STOPONERROR}" != X && myexit 1
fi
rm -f ${PMIDS}

if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && myexit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi


# ----------------------------------------
# DATA command causes pmilter to exit
TEST=3
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
RCPT=x${TEST}@y.z
rm -f ${PMIDS}
PMOPTS="-r d=${PMEXIT}"
if ${SHELL} ${SCRIPTS}/smtpcnf.sh -V '-d 8' ${PMPRG} ${PMOPT} -P "${PMOPTS}" -Z 'smtpc2' -c '-E' -E 1 -A 1 -X 1 "$@" -Sa${TEST}@b.c -R${RCPT} -8 s
then
  ERR=false
else
    ERR=true
    echo "$0: test ${TEST} failed"
    test X"${MTA_STOPONERROR}" != X && myexit 1
fi
rm -f ${PMIDS}

if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && myexit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi


# ----------------------------------------
# final dot causes pmilter to exit
TEST=4
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
RCPT=x${TEST}@y.z
rm -f ${PMIDS}
PMOPTS="-r b=${PMEXIT}"
if ${SHELL} ${SCRIPTS}/smtpcnf.sh -V '-d 8' ${PMPRG} ${PMOPT} -P "${PMOPTS}" -Z 'smtpc2' -c '-E' -E 1 -A 1 -X 1 "$@" -Sa${TEST}@b.c -R${RCPT} -8 s
then
  ERR=false
else
    ERR=true
    echo "$0: test ${TEST} failed"
    test X"${MTA_STOPONERROR}" != X && myexit 1
fi
rm -f ${PMIDS}

if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && myexit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi


# ----------------------------------------
# pmilter exits during message replacement
TEST=5
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
RCPT=x${TEST}@y.z
rm -f ${PMIDS}
PMOPTS="-r R=${PMEXIT} -B /dev/null"
if ${SHELL} ${SCRIPTS}/smtpcnf.sh -V '-d 8' ${PMPRG} ${PMOPT} -P "${PMOPTS}" -Z 'smtpc2' -c '-E' -E 1 -A 1 -X 1 "$@" -Sa${TEST}@b.c -R${RCPT} -8 s
then
  ERR=false
else
    ERR=true
    echo "$0: test ${TEST} failed"
    test X"${MTA_STOPONERROR}" != X && myexit 1
fi
rm -f ${PMIDS}

if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && myexit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi

# ----------------------------------------
# do not start pmilter at all
TEST=6
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
RCPT=x${TEST}@y.z
if ${SHELL} ${SCRIPTS}/smtpcnf.sh -V '-d 8' -Z 'smtpc2' -c '-E' -E 1 -A 1 -X 1 "$@" -Sa${TEST}@b.c -R${RCPT} -8 s
then
  ERR=false
else
    ERR=true
    echo "$0: test ${TEST} failed"
    test X"${MTA_STOPONERROR}" != X && myexit 1
fi
rm -f ${PMIDS}

if ${ERR}
then
    echo "$0: test ${TEST} check failed"
    ERRS=`expr ${ERRS} + 1 `
    test X"${MTA_STOPONERROR}" != X && myexit 1
else
    ${VERBOSE} && echo "test ${TEST} succeeded"
fi
fi


# ----------------------------------------
# end
if test ${ERRS} -eq 0
then
  exit 0
else
  echo "$0: ${ERRS} error(s)"
  myexit 1
fi
