#!/bin/sh
# $Id: t-conf-array-0.sh,v 1.5 2011/01/04 16:29:08 ca Exp $
#
# test inheritance
#

test -s stop && exit 1

# source directory of this (and other) shell script
SD=`dirname $0`

ERRS=0

CNF=sma0.conf
OUT=sma0.out
OK=sma0.ok

PRG=./t-conf-array-0

rm -f ${CNF} ${OUT} ${OK}

check() {
if ${PRG} -f ${CNF} "$@" >${OUT}
then
  if diff ${OK} ${OUT}
  then
    :
  else
    ERRS=`expr ${ERRS} + 1 `
  fi
else
  ERRS=`expr ${ERRS} + 1 `
fi
}

# ----------------
TEST=1
cat > ${CNF} <<EOF
max_ta = 12;
max_conn = 21;
connection_limits {
  rcpt_domain = aol.com;
  max_ta = 4;
}
connection_limits {
  rcpt_domain = hotmail.com;
}
EOF
cat > ${OK} <<EOF
# global max ta
max_ta=12;
# global max conn
max_conn=21;
# global max rate
max_rate=100;
# connection limit declarations
connection_limits {
  rcpt_domain="aol.com";
  # max ta
  max_ta=4;
  # max conn
  max_conn=21;
  # max rate
  max_rate=0;
}
connection_limits {
  rcpt_domain="hotmail.com";
  # max ta
  max_ta=12;
  # max conn
  max_conn=21;
  # max rate
  max_rate=0;
}
EOF
check

# ----------------
TEST=2
cp ${OK} ${CNF}
check

# ----------------
TEST=3
cat > ${CNF} <<EOF
max_ta = 12;
max_conn = 21;
connection_limits { rcpt_domain = aol.com; max_ta = 4; }
connection_limits { rcpt_domain = hotmail.com; max_rate = 121; }
EOF
cat > ${OK} <<EOF
# global max ta
max_ta=12;
# global max conn
max_conn=21;
# global max rate
max_rate=100;
# connection limit declarations
connection_limits {
  rcpt_domain="aol.com";
  # max ta
  max_ta=4;
  # max conn
  max_conn=21;
  # max rate
  max_rate=0;
}
connection_limits {
  rcpt_domain="hotmail.com";
  # max ta
  max_ta=12;
  # max conn
  max_conn=21;
  # max rate
  max_rate=121;
}
rcpt_domain=aol.com, max_ta=4, max_conn=21, max_rate=0
rcpt_domain=aol1.com, status=not_found
rcpt_domain=hotmail.com, max_ta=12, max_conn=21, max_rate=121
EOF
check aol.com aol1.com hotmail.com

# ----------------
# does not (yet?) work: inheritance from anonymous sibling section
# TEST=4
# cat > ${CNF} <<EOF
# connection_limits { max_ta = 8; }
# connection_limits aol { rcpt_domain = aol.com; max_ta = 4; }
# connection_limits hotmail { rcpt_domain = hotmail.com; max_conn = 121; }
# EOF
# cat > ${OK} <<EOF
# # global max ta
# max_ta=99;
# # global max conn
# max_conn=10;
# # global max rate
# max_rate=100;
# # connection limit declarations
# connection_limits {
#   # max ta
#   max_ta=8;
#   # max conn
#   max_conn=0;
#   # max rate
#   max_rate=0;
# }
# connection_limits aol {
#   rcpt_domain="aol.com";
#   # max ta
#   max_ta=4;
#   # max conn
#   max_conn=21;
#   # max rate
#   max_rate=0;
# }
# connection_limits hotmail {
#   rcpt_domain="hotmail.com";
#   # max ta
#   max_ta=8;
#   # max conn
#   max_conn=121;
#   # max rate
#   max_rate=0;
# }
# rcpt_domain=aol.com, max_ta=4, max_conn=0, max_rate=0
# EOF
# check aol.com

# ----------------
if test ${ERRS} -eq 0
then
  rm -f ${CNF} ${OUT} ${OK}
  exit 0
else
  echo "$0: ${ERRS} error(s)"
  exit 1
fi
