/*
 * Copyright (c) 2010 Claus Assmann
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the license/LICENSE.3C file which can be found at the
 * top level of this source code distribution.
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: strf1chr.c,v 1.1 2013/10/01 02:02:25 ca Exp $")
#include "sm/assert.h"
#include "sm/error.h"
#include "sm/ctype.h"
#include "sm/str.h"
#include "sm/str-int.h"

/*
**  SM_STR_F1CHR -- find first occurrence of a char in str
**
**	Parameters:
**		str -- string in which to find delim
**		delim -- char to find
**		offset -- where to start searching
**		pidx -- index in string at which delim appears first
**			only valid for SM_SUCCESS
**
**	Returns:
**		usual error code
*/

sm_ret_T
sm_str_f1chr(sm_str_P str, uchar delim, uint offset, uint *pidx)
{
	uchar ch;
	uint len;
	int i;

	SM_IS_BUF(str);
	SM_REQUIRE(pidx != NULL);

	len = sm_str_getlen(str);

	/* search for delimiter */
	for (i = offset; i < len; i++) {
		ch = sm_str_rd_elem(str, i);
		if (delim == ch) {
			*pidx = i;
			return SM_SUCCESS;
		}
	}
	return sm_error_perm(SM_EM_STR, SM_E_NOTFOUND);
}
