/*
 * Copyright (c) 2004 Sendmail, Inc. and its suppliers.
 *	All rights reserved.
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the sendmail distribution.
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: t-id.c,v 1.3 2011/01/28 16:13:41 ca Exp $")

#include "sm/ctype.h"
#include "sm/sysexits.h"
#include "sm/error.h"

#include <stdio.h>

static int Verbose = 0;

static void
usage(const char *prg)
{
	fprintf(stderr,
		"usage: %s [options]\n"
		"options:\n"
		"-o        dummy option\n"
		"-i id     id\n"
		"-V        increase verbosity\n"
		, prg);
	exit(EX_USAGE);
}

int
main(int argc, char *argv[])
{
	bool got;
	int c, id, oargc;
	char *prg, *fn;
	FILE *fp;
	char args[1024];

	prg = argv[0];
	id = -1;
	got = false;
	oargc = argc;
	args[0] = '\0';
	while ((c = getopt(argc, argv, "hi:oV")) != -1)
	{
		switch (c)
		{
		  case 'o':
			got = true;
			strlcat(args, "-o ", sizeof(args));
			break;
		  case 'i':
			strlcat(args, "-i", sizeof(args));
			strlcat(args, optarg, sizeof(args));
			strlcat(args, " ", sizeof(args));
			id = strtol(optarg, NULL, 0);
			break;
		  case 'V':
			strlcat(args, "-V ", sizeof(args));
			++Verbose;
			break;
		  case 'h':
		  case '?':
		  default:
			usage(prg);
			break;
		}
	}
	argc -= optind;
	argv += optind;
	if (argc > 0)
	{
		fn = argv[0];
		fp = fopen(fn, "a");
		if (fp == NULL)
			return errno;
		fprintf(fp, "id=%d, pid=%ld, argc=%d, got=%d, args=%s\n",
			id, (long) getpid(), oargc, got, args);
		fclose(fp);
		sleep(2);
	}
	exit(0);
}
