#!/bin/sh
# $Id: t-access-1.sh,v 1.21 2014/05/29 14:36:57 ca Exp $
# Copyright (c) 2004, 2005 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ------------------------------------------------------------
# Description:
# Script to test access map restrictions for RFC2821 addresses.
# Uses smar, t-access-0, access map, t-mm, startsmar.sh
# ------------------------------------------------------------
# Note: smar and t-access-0 are running asynchronous, hence
# there must be no expected order in the output file.
#

TPRG=./t-access-0
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../smar
fi
. ${SD}/common.sh

if test X"`uname`" != "XOSF1"
then
while getopts s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

rm -f ${ACCMAP} ${SOCK} ${PIDS} ${MT}

# create access map for tests
${VALGRIND} ${MM} -t'	' -F ${ACCMAP} <<EOF
to:not	error:550 5.7.0 no to:not
to:not1@b.c	error:551 5.7.1 no to:not1@b.c
to:@not2.c	error:552 5.7.2 no to:@not2.c
EOF

trap killit 2


# start SMAR
${SHELL} ${SD}/startsmar.sh ${SMAROPTS} || exit 1
rm -f ${OUT} ${IP} ${OK}

TEST=1
# ----------------------------------------
${VALGRIND} ${TPRG} -r '<not@test4.dom>' > ${OUT} 2>&1
grep '^react=' ${OUT} > ${IP}
cat > ${OK} <<EOF
react=statt, ret=0, statt='550 5.7.0 no to:not
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi

TEST=2
# ----------------------------------------
${VALGRIND} ${TPRG} -r '<not1@b.c>' '<any2@not2.c>' 2>&1 | sort > ${OUT}
grep '^react=' ${OUT} > ${IP}
sort > ${OK} <<EOF
react=statt, ret=0, statt='551 5.7.1 no to:not1@b.c
react=statt, ret=0, statt='552 5.7.2 no to:@not2.c
EOF
ERR=false
if diff ${OK} ${IP} >/dev/null
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi

TEST=3
# ----------------------------------------
${VALGRIND} ${TPRG} -r '<not1@b.c.d>' '<any2@not2.d>' > ${OUT} 2>&1
grep '^react=' ${OUT} > ${IP}
cat > ${OK} <<EOF
react=no_match
react=no_match
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
  test X"${MTA_STOPONERROR}" != X && exit ${ERRS}
fi

# stop SMAR
for i in `cat ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi
sleep 3

rm -f ${OUT} ${IP} ${OK}
exit ${ERRS}
