/*
 * Copyright (c) 2012 Claus Assmann
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the license/LICENSE.3C file which can be found at the
 * top level of this source code distribution.
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: t-mtparse-0.c,v 1.15 2013/09/21 19:54:46 ca Exp $")
#include "sm/common.h"
#include "sm/assert.h"
#include "sm/error.h"
#include "sm/ctype.h"
#include "sm/io.h"
#include "sm/net.h"
#include "sm/misc.h"
#include "sm/sysexits.h"
#include "sm/test.h"
#include "smar.h"
#define SMAR_LOG_DEFINES 1
#include "log.h"
#include "mtparse.h"
#include "t-init.h"

int Loglevel = 0;
static int Verbose = 0;

static void
prtcnf(ar_mtcnf_P ar_mtcnf)
{
	if (Verbose) {
		sm_io_fprintf(smioerr,
			"protocol=%d\n"
			"port=%d\n"
			"host=%s\n"
			"ip[0]=%s\n"
			"n_ip=%u\n"
			"ip[0]=%I\n"
			"flags=%#x\n"
			, ar_mtcnf->ar_mt_cnf_prot
			, ar_mtcnf->ar_mt_cnf_port
			, ar_mtcnf->ar_mt_cnf_host
			, ar_mtcnf->ar_mt_cnf_ips[0]
			, ar_mtcnf->ar_mt_cnf_n_ips
			, &ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr
			, ar_mtcnf->ar_mt_cnf_flags
			);
	}
}

static sm_ret_T
test_mtparse(smar_clt_ctx_P smar_clt_ctx, ar_mtcnf_P ar_mtcnf, sm_str_P mtrhs)
{
	sm_ret_T ret;

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "host=meta1.org;");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret == SM_SUCCESS);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_prot);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_port);
	SM_TEST(strcmp(ar_mtcnf->ar_mt_cnf_host,"meta1.org") == 0);
	SM_TEST(NULL == ar_mtcnf->ar_mt_cnf_ips[0]);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_n_ips);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr.ipa_addr.ipv4_addr);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "protocol=esmtp; host=meta1.org;");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret == SM_SUCCESS);
	SM_TEST(SMAR_PROT_ESMTP == ar_mtcnf->ar_mt_cnf_prot);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_port);
	SM_TEST(strcmp(ar_mtcnf->ar_mt_cnf_host,"meta1.org") == 0);
	SM_TEST(NULL == ar_mtcnf->ar_mt_cnf_ips[0]);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_n_ips);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr.ipa_addr.ipv4_addr);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "protocol=lmtp; port=6789; ipv4={1.2.3.4, 10.11.12.123};");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret == SM_SUCCESS);
	SM_TEST(SMAR_PROT_LMTP == ar_mtcnf->ar_mt_cnf_prot);
	SM_TEST(6789 == ar_mtcnf->ar_mt_cnf_port);
	SM_TEST(NULL == ar_mtcnf->ar_mt_cnf_host);
	SM_TEST(NULL != ar_mtcnf->ar_mt_cnf_ips[0]);
	SM_TEST(2 == ar_mtcnf->ar_mt_cnf_n_ips);
	SM_TEST(inet_addr("1.2.3.4") == ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr.ipa_addr.ipv4_addr);
	SM_TEST(inet_addr("10.11.12.123") == ar_mtcnf->ar_mt_cnf_ipp[1].ipp_addr.ipa_addr.ipv4_addr);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "protocol=lmtp; ip={1.2.3.4, 10.11.12.123};");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret != SM_SUCCESS);
	SM_TEST(SMAR_PROT_LMTP == ar_mtcnf->ar_mt_cnf_prot);
	SM_TEST(NULL == ar_mtcnf->ar_mt_cnf_host);
	SM_TEST(NULL != ar_mtcnf->ar_mt_cnf_ips[0]);
	SM_TEST(2 == ar_mtcnf->ar_mt_cnf_n_ips);
	SM_TEST(inet_addr("1.2.3.4") == ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr.ipa_addr.ipv4_addr);
	SM_TEST(inet_addr("10.11.12.123") == ar_mtcnf->ar_mt_cnf_ipp[1].ipp_addr.ipa_addr.ipv4_addr);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "host=meta1.org; ip={1.2.3.4};");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret != SM_SUCCESS);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_prot);
	SM_TEST(NULL != ar_mtcnf->ar_mt_cnf_host);
	SM_TEST(NULL != ar_mtcnf->ar_mt_cnf_ips[0]);
	SM_TEST(1 == ar_mtcnf->ar_mt_cnf_n_ips);
	SM_TEST(inet_addr("1.2.3.4") == ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr.ipa_addr.ipv4_addr);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "protocol=smtp; ip={1.2.3.4};");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret != SM_SUCCESS);
	SM_TEST(SMAR_PROT_LMTP != ar_mtcnf->ar_mt_cnf_prot);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "ip={1.2.3.};");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret != SM_SUCCESS);
	SM_TEST(SMAR_PROT_LMTP != ar_mtcnf->ar_mt_cnf_prot);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

	sm_str_clr(mtrhs);
	ret = sm_str_scat0(mtrhs, "protocol=esmtp; flags=no_MX_lookup; host=meta1.org;");
	SM_TEST_E(ret == SM_SUCCESS);
	sm_memzero(ar_mtcnf, sizeof(*ar_mtcnf));
	ret = smar_mt_parse(smar_clt_ctx, mtrhs, ar_mtcnf);
	SM_TEST_E(ret == SM_SUCCESS);
	SM_TEST(SMAR_PROT_ESMTP == ar_mtcnf->ar_mt_cnf_prot);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_port);
	SM_TEST(strcmp(ar_mtcnf->ar_mt_cnf_host,"meta1.org") == 0);
	SM_TEST(NULL == ar_mtcnf->ar_mt_cnf_ips[0]);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_n_ips);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_ipp[0].ipp_addr.ipa_addr.ipv4_addr);
	SM_TEST(0 == ar_mtcnf->ar_mt_cnf_flags);
	prtcnf(ar_mtcnf);
	smar_mtcnf_clear(ar_mtcnf);
#if SM_HEAP_CHECK
	if (HEAP_CHECK)
		sm_heap_report(smioerr, 3);
#endif

  error:
	return ret;
}

int
main(int argc, char *argv[])
{
	int c, i;
	sm_ret_T ret;
	sm_str_P mtrhs;
	ar_mtcnf_T ar_mtcnf;
	smar_clt_ctx_P smar_clt_ctx;
	smar_ctx_T smar_ctx;

#if SM_HEAP_CHECK
	SmHeapCheck = 1;
#endif

	while ((c = getopt(argc, argv, "V")) != -1) {
		switch (c) {
		  case 'V':
			++Verbose;
			break;
		  default:
			return EX_USAGE;
		}
	}

	sm_test_begin(argc, argv, "test mtparse 0");
	argc -= optind;
	argv += optind;

	ret = t_smar_0_init(&smar_ctx, 0);
	SM_TEST_E(ret == SM_SUCCESS);
	ret = smar_clt_new(&smar_ctx, &smar_clt_ctx);
	SM_TEST_E(ret == SM_SUCCESS);

	mtrhs = sm_str_new(NULL, 16, 256);
	SM_TEST_E(mtrhs != NULL);

	if (argc < 2) {
		ret = test_mtparse(smar_clt_ctx, &ar_mtcnf, mtrhs);
	}
	else {
		for (i = 1; i < argc; i++) {
			sm_str_clr(mtrhs);
			ret = sm_str_scat0(mtrhs, argv[i]);
			SM_TEST_E(ret == SM_SUCCESS);
sm_io_fprintf(smioerr, "parse %@S\n", mtrhs);
			sm_memzero(&ar_mtcnf, sizeof(ar_mtcnf));
			ret = smar_mt_parse(smar_clt_ctx, mtrhs, &ar_mtcnf);
			SM_TEST_E(ret == SM_SUCCESS);
sm_io_fprintf(smioerr, "parsed=%r\n", ret);
			prtcnf(&ar_mtcnf);
		}
	}
 error:
	return sm_test_end();
}
