#!/bin/sh
# $Id: t-mtparse-2.sh,v 1.7 2013/09/23 21:01:42 ca Exp $
#
# ------------------------------------------------------------
# Description:
# mailertable routing tests by contacting SMAR, using BDB
# uses t-smar-1, startsmar.sh, t-mm
# ------------------------------------------------------------
#

# path to programs
P=..
TPRG=./t-smar-1
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../smar
fi
. ${SD}/common.sh

CONF=mt.conf
MAPTYPES=""

if test X"`uname`" != "XOSF1"
then
while getopts s:T:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    T) MAPTYPES="${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

rm -f ${SOCK} ${PIDS}

# prepare mailertable
${CAT} > ${MT} <<EOF
mta.org	{protocol=esmtp; flags=no_MX_lookup; host=a1.meta1.org;}
EOF

${MM} -l 0 > ${MMMAPC}

# create aliases map for smar
rm -f ${ALIMAP}
${MM} <<EOF
user:	local:
EOF
if test $? -ne 0
then
  echo t-mm failed
  exit 1
fi

TEST=0

# start SMAR
${SHELL} ${SD}/startsmar.sh -d 9 -m ${SMAROPTS} || exit 1

rm -f ${OUT} ${IP} ${OK}

TEST=`expr $TEST + 1 `
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@mta.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=10.0.1.1 [a000101]
EOF
if diff ${OK} ${IP}
then
  rm -f ${OUT} ${IP} ${OK}
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

# stop SMAR
for i in `${CAT} ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi


if test X"${MAPTYPES}" = "X"
then
./smar -l 1 | grep ':A:L:.:F' >${MAPC}
MAPTYPES="`sed -e 's/^\([a-zA-Z][a-zA-Z0-9_]*\):A:L:.:F/\1/' < ${MAPC}`"
fi
# list map classes available for t-mm
${MM} -l 0 > ${MMMAPC}
for maptype in ${MAPTYPES}
do

if grep ${maptype} ${MMMAPC} >/dev/null
then

rm -f ${MTMAPDB}
${MM} -t'	' -T ${maptype} -F ${MTMAPDB} < ${MT}

${CAT} > ${CONF} <<EOF
smar {
 map mt { type=${maptype}; file=${MTMAPDB}; }
 mailertable { name=mt; }
}
EOF

# start SMAR
${SHELL} ${SD}/startsmar.sh -d 9 -m -f ${CONF} ${SMAROPTS} || exit 1

rm -f ${OUT} ${IP} ${OK}

TEST=`expr $TEST + 1 `
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@mta.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=10.0.1.1 [a000101]
EOF
if diff ${OK} ${IP}
then
  rm -f ${MTMAPDB} ${MT} ${OUT} ${IP} ${OK} ${CONF}
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
break
fi

# stop SMAR
for i in `${CAT} ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi

else
  echo "$0: ${maptype} not available for ${MM}"
fi
done

rm -f ${MT}

exit ${ERRS}
