#!/bin/sh
# $Id: t-smar-0.sh,v 1.36 2013/09/23 21:01:42 ca Exp $
# Copyright (c) 2003-2005 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ------------------------------------------------------------
# Description:
# simple DNS MX+A lookup tests by contacting SMAR
# uses t-smar-1 and startsmar.sh
# Note: this program relies on the meta1.org DNS server.
# ------------------------------------------------------------
#

if test X"${MTA_NO_DNS_TEST}" != "X"
then
  echo "SKIPPED: $0: MTA_NO_DNS_TEST is set"
  exit 0
fi

if test X"${MTA_TEST_DNS_TIMING}" = "X"
then
  echo "SKIPPED: $0: MTA_TEST_DNS_TIMING is not set"
  exit 0
fi

TPRG=./t-smar-1
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../smar
fi
. ${SD}/common.sh

if test X"`uname`" != "XOSF1"
then
while getopts a:s:V FLAG
do
  case "${FLAG}" in
    a) SMAROPTS="${OPTARG}";;
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

rm -f ${SOCK} ${PIDS}

# prepare mailertable for MX cutoff check
${CAT} > ${MT} <<EOF
host20.meta1.org	lmtp:
EOF

# start SMAR
${SHELL} ${SD}/startsmar.sh ${SMAROPTS} || exit 1

rm -f ${OUT} ${IP} ${OK}

TEST=1
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
# test MX lookups for two known domains
${VALGRIND} ${TPRG} -M -VVVV '<a@meta1.esmtp.org>' '<b@meta1.meta1.org>' > ${OUT} 2>&1

#mine.esmtp.org:
#IP[0]=134.245.248.42 [86f5f82a]

grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=10.1.2.3 [a010203]
IP[0]=10.1.2.4 [a010204]
IP[1]=10.1.2.5 [a010205]
EOF

if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

rm -f ${OUT} ${IP} ${OK}
fi

TEST=2
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
# test MX lookups with mixed case domain names
${VALGRIND} ${TPRG} -M -VVVV '<a@mx1.MeTA1.Org>' '<a@MX1.MeTa1.ORG>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
cat > ${OK} <<EOF
IP[0]=10.0.0.1 [a000001]
IP[0]=10.0.0.1 [a000001]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi
rm -f ${OUT} ${IP} ${OK}
fi


TEST=3
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
# test MX cutoff:
# hence only the first IP address is returned
${VALGRIND} ${TPRG} -VVVV '<a@list10-1.meta1.org>' > ${OUT} 2>&1

grep '^IP' ${OUT} | sort > ${IP}
sort > ${OK} <<EOF
IP[0]=10.0.0.1 [a000001]
EOF

if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

rm -f ${OUT} ${IP} ${OK}
fi

# stop SMAR
for i in `cat ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi

exit ${ERRS}
