#!/bin/sh
# $Id: t-smar-rvrs-3.sh,v 1.9 2013/12/08 16:28:27 ca Exp $
#
# Copyright (c) 2013 Claus Assmann
#
# By using this file, you agree to the terms and conditions set
# forth in the license/LICENSE.3C file which can be found at the
# top level of this source code distribution.
#
# ------------------------------------------------------------
# Description:
# Script to test access map restrictions (only IP addresses)
# and reverse lookups (PTR).
# Uses smar, t-smar-3, access map, t-mm, startsmar.sh
# ------------------------------------------------------------
#

if test X"${MTA_NO_DNS_TEST}" != "X"
then
  echo "SKIPPED: $0: MTA_NO_DNS_TEST is set"
  exit 0
fi
if test X"${MTA_HAVE_10_INADDRARPA}" != "Xtrue"
then
  echo "SKIPPED: $0: MTA_HAVE_10_INADDRARPA is not set to true"
  exit 0
fi
if [ X"${MTA_NO_IPV6_TEST}" != "X" ]
then
  echo "SKIPPED: $0: MTA_NO_IPV6_TEST set"
  exit 0
fi

TPRG=./t-smar-3
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../smar
fi
. ${SD}/common.sh

chkctoprg ${TPRG} MTA_NETINET6

if test X"`uname`" != "XOSF1"
then
while getopts s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

rm -f ${ACCMAP} ${SOCK} ${PIDS}

# create access map for tests
${MM} -t'	' -F ${ACCMAP} <<EOF
cltaddr:fec0::2fd:87fe:1e72:1d4f	ok
cltresolve:NO	error:450 4.7.1 get a name
EOF

# start SMAR
${SHELL} ${SD}/startsmar.sh -d 9 ${SMAROPTS} || exit 1
rm -f ${OUT} ${IP} ${OK}

TEST=1
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} fec0::2fd:87fe:1e72:1d4f > ${OUT} 2>&1
grep '^react=' ${OUT} > ${IP}
cat > ${OK} <<EOF
react=rvrs_st, ret=0, stat=1
react=rvrs_name, ret=0, name=ipv6-1.meta1.org.
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi
fi

TEST=2
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} fec0::2:3:2c4:f0af:f948:efaf > ${OUT} 2>&1
grep '^react=' ${OUT} > ${IP}
cat > ${OK} <<EOF
react=statt, ret=0, statt='450 4.7.1 get a name
react=rvrs_st, ret=0, stat=2
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi
fi

TEST=3
if echo "${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
# ----------------------------------------
${VALGRIND} ${TPRG} fec0::dead:3:2c4:f0af:f948:efaf > ${OUT} 2>&1
grep '^react=' ${OUT} > ${IP}
cat > ${OK} <<EOF
react=statt, ret=0, statt='450 4.7.1 get a name
react=rvrs_st, ret=0, stat=2
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi
fi


# stop SMAR
for i in `cat ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi
sleep 3

test ${ERRS} -eq 0 && rm -f ${OUT} ${IP} ${OK}

exit ${ERRS}
